
# Dialog Flow Pipeline

**Dialog Flow Pipeline** is python module add-on for [Dialog Flow Framework](https://github.com/deepmipt/dialog_flow_framework), a free and open-source software stack for creating chatbots, released under the terms of Apache License 2.0.


[Dialog Flow Pipeline](../..) allows you to ...
[![Codestyle](../../../workflows/codestyle/badge.svg)](../../../actions)
[![Tests](../../../workflows/test_coverage/badge.svg)](../../../actions)
[![License Apache 2.0](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](LICENSE)
![Python 3.6, 3.7, 3.8, 3.9](https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-green.svg)

<!-- TODO: uncomment one of these to add badges to your project description -->
<!-- [![Documentation Status](https://df_pipeline.readthedocs.io/en/stable/?badge=stable)]() See readthedocs.io -->
<!-- [![Coverage Status]()]() See coveralls.io -->
<!-- [![PyPI](https://img.shields.io/pypi/v/df_pipeline)](https://pypi.org/project/df_pipeline/) -->
<!-- [![Downloads](https://pepy.tech/badge/df_pipeline)](https://pepy.tech/project/df_pipeline) -->

# Quick Start
## Installation
```bash
pip install df_pipeline
```

## Basic example
```python

```

To get more advanced examples, take a look at [examples](examples) on GitHub.

# Contributing to the Dialog Flow Pipeline

Please refer to [CONTRIBUTING.md](CONTRIBUTING.md).